function AdaptExc
%function Par= AdaptExc(Par);
% Simulates adaptation of vessels and chambers to current hemodynamics
% Theo Arts, Maastricht University, April 23, 2008

global Par
save ParTemp Par; %saves intermediate solution
% 
% Assessment of stationarity of flows
Str= '[Par.ValveRVen.q,Par.ValveRArt.q,Par.ValveLVen.q,Par.ValveLArt.q]';
Aux= eval(Str); FlowVec= mean(Aux(2:end,:));
 % test on presence of FlowVec with right size
if isfield(Par.Adapt, 'FlowVec')
    FlowVecPrev= Par.Adapt.FlowVec;
    if length(FlowVecPrev)~=length(FlowVec);
        FlowVecPrev= 0*FlowVec;
    end
else
    FlowVecPrev= 0*FlowVec;
end
ErrFlow= std(FlowVec-FlowVecPrev)/mean(FlowVec);
Par.Adapt.FlowVec= FlowVec;
disp('Flow RVen RAv RArt LVen LAv LArt Err (ml/s), ErrFlow :');
disp(num2str([FlowVec*1e6,ErrFlow],4));
%=== end flow error calculation


%=== Fast adapt convergence to reach steady state
Par.Adapt.StrInOut={...
    'Par.Lv.Sarc.SfPas',...
    'Par.Sv.Sarc.SfPas',...
    'Par.Rv.Sarc.SfPas',...
    'Par.La.Sarc.SfPas',...
    'Par.Ra.Sarc.SfPas',...
    'Par.Lv.AmRef',...
    'Par.Sv.AmRef',...
    'Par.Rv.AmRef',...
    'Par.La.AmRef',...
    'Par.Ra.AmRef',...
    'Par.TubeRVen.AWall',...
    'Par.TubeRArt.AWall',...
    'Par.TubeLVen.AWall',...
    'Par.TubeLArt.AWall',...
    'Par.Peri.pAdapt',...
    'Par.Lv.VWall',...
    'Par.Sv.VWall',...
    'Par.Rv.VWall',...
    'Par.La.VWall',...
    'Par.Ra.VWall',...
    'Par.Ra.V',...
    'Par.Rv.V',...
    'Par.La.V',...
    'Par.Lv.V',...
    'Par.TubeRVen.V',...
    'Par.TubeRArt.V',...
    'Par.TubeLVen.V',...
    'Par.TubeLArt.V',...
 };

%====

if ErrFlow<0.10;

    Par2InOut;% store input signals
    
    % Peripheral resistance settings
    Par.LRp.R = (Par.General.p0-mean(Par.TubeRVen.p))/Par.General.q0;
    Par.RRp.R = Par.General.pDropPulm/mean(Par.RRp.q); % NotEqTo q0 due to shunt flows

    % Estimate AV-delay
    TauAv=0.185*Par.General.tCycle;
    Par.General.TauAv= TauAv;

    %=== Adapt tube wall thickness
    disp('Sequence: LArt,RArt,LVen,RVen')
    Par.TubeLArt= TubeAdapt(Par.TubeLArt,{'WallVolume'});
    Par.TubeRArt= TubeAdapt(Par.TubeRArt,{'WallVolume'});
    Par.TubeLVen= TubeAdapt(Par.TubeLVen,{'WallVolume'});
    Par.TubeRVen= TubeAdapt(Par.TubeRVen,{'WallVolume'});
    
    %=== Adapt sheet properties
    JunctionAdapt; %TriSeg correction of AmRef per sheet by EAmRef
    % anatomical dimensions, i.e. larger septum
    disp('Sequence: La,Ra,Lv,Sv,Rv')
    [Par.La,ELa]= SheetAdapt(Par.La,{'WallVolume','WallArea','EcmStress'});
    [Par.Ra,ERa]= SheetAdapt(Par.Ra,{'WallVolume','WallArea','EcmStress'});
    [Par.Lv,ELv]= SheetAdapt(Par.Lv,{'WallVolume','WallArea','EcmStress'});
    [Par.Sv,ESv]= SheetAdapt(Par.Sv,{'WallVolume','WallArea','EcmStress'});
    [Par.Rv,ERv]= SheetAdapt(Par.Rv,{'WallVolume','WallArea','EcmStress'});

    %=== Adapt pericardium
    Par.Peri=PeriAdapt(Par.Peri);
    
    ErrSheet=sqrt(mean([ELv,ESv,ERv,ELa,ERa].^2));% RMS error

    disp(['VWall(ml)= ',num2str( 1e6*(Par.Lv.VWall+Par.Sv.VWall) )]);
    disp(['ErrSheet = ',num2str( ErrSheet )]);
        
    Par2InOut;% store output signals
end


% === if Error==small, ending is made faster
if size(Par.Adapt.Out,1)>1; % Escape if steady state is reached
    ErrVec= log( Par.Adapt.Out(end,:)./Par.Adapt.In(end,:) );
    if sqrt(mean(ErrVec .^2 ))<0.001
        Par.General.tEnd= Par.General.tEnd-0.5*(Par.General.tEnd-Par.t(end));
    end
end;
% === Faster Steady State
if Par.Adapt.Fast;
    %=== ERROR criterium on flow stationarity
    SteadyState(0.2); % sets new initial conditions to StrInOut-variables
end
disp(' ');

%=== make ready for next beat
Par2SVar;
CircSVarDot(0,Par.SVar(end,:)',[]);
return


%==========================================================================
% Auxilary functions <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
%==========================================================================
function Peri=PeriAdapt(Peri)
pMax = max(Peri.p);
Fac_pMax= Peri.pAdapt/pMax;
Peri.VRef= Peri.VRef/(Fac_pMax^(0.3/Peri.k));
disp(['Pericard adaptation: ',num2str(log(Fac_pMax))]);
return

function JunctionAdapt
% Adjustment factor for Adapt.SfPasMax for sheets around junctions
% Keeps total heart geometry in shape by variation of passive stiffness
% per sheet. Heuristic approach, not much physiological background.
% EAmRef= needed increase of area AmRef, (value>0) ->  dilatation
global Par
AL=Par.Lv.AmRef;
AS=Par.Sv.AmRef;
AR=Par.Rv.AmRef;
Par.Lv.EAmRef= 0;
% Par.Sv.EAmRef= 5*log( AL*AR/((AL+AR)*AS*1.5) );
Par.Sv.EAmRef= 5*log( AL*AR/((AL+AR)*AS*1.0) );% larger Sv.AmRef
Par.Rv.EAmRef= 0;
return
