function AdaptRest
%function Par= AdaptRest(Par);
% Simulates adaptation of vessels and chambers to current hemodynamics

global Par
save ParTemp Par; %saves intermediate solution

%=== ERROR criterium on flow stationarity
FlowVec= mean([Par.ValveRVen.q,Par.ValveRArt.q,...
    Par.ValveLVen.q,Par.ValveLArt.q]);
if isfield(Par.Adapt, 'FlowVec')
    FlowVecPrev= Par.Adapt.FlowVec;
    if length(FlowVecPrev)~=length(FlowVec);
        FlowVecPrev= 0*FlowVec;
    end
else
    FlowVecPrev= 0*FlowVec;
end
ErrFlow= std(FlowVec-FlowVecPrev)/mean(FlowVec); %...
    %+ abs(1- mean(Par.ValveRVen.q)/Par.General.q0);
Par.Adapt.FlowVec= FlowVec;
disp('Flow RVen RArt LVen LArt Err (ml/s), ErrFlow :');
disp(num2str([FlowVec*1e6,ErrFlow],4));
%=== end flow error calculation

%=== Fast adapt convergence records
Par.Adapt.StrInOut={...
    'Par.Ra.V',...
    'Par.Rv.V',...
    'Par.La.V',...
    'Par.Lv.V',...
    'Par.TubeRVen.V',...
    'Par.TubeRArt.V',...
    'Par.TubeLVen.V',...
    'Par.TubeLArt.V',...
    'Par.TubeRVen.A0',...
    'Par.TubeRArt.A0',...
    'Par.TubeLVen.A0',...
    'Par.TubeLArt.A0',...
     };


%=== Carrying out adaptation
if (ErrFlow<0.05+0.1*Par.Adapt.Fast); % Adaptation only if ErrFlow indicates 'stationarity'

    Par2InOut;% store input signals
    
    % Peripheral resistance settings
    Par.LRp.R = (Par.General.p0-mean(Par.TubeRVen.p))/Par.General.q0;
    Par.RRp.R = Par.General.pDropPulm/mean(Par.RRp.q); % NotEqTo q0 due to shunt flows

    % Estimate AV-delay
    TauAv=0.185*Par.General.tCycle;
    Par.General.TauAv= TauAv;

    %=== Adapt tube diameters
    Par.TubeLArt= TubeAdapt(Par.TubeLArt,{'Diameter'});
    Par.TubeRArt= TubeAdapt(Par.TubeRArt,{'Diameter'});
    Par.TubeLVen= TubeAdapt(Par.TubeLVen,{'Diameter'});
    Par.TubeRVen= TubeAdapt(Par.TubeRVen,{'Diameter'});
    
    if 1 %Adapt valve diameters to tube diameters
        Par.ValveLArt.AOpen=mean(Par.TubeLArt.A);
        Par.ValveRArt.AOpen=mean(Par.TubeRArt.A);
        Par.ValveLVen.AOpen=mean(Par.TubeLVen.A);
        Par.ValveRVen.AOpen=mean(Par.TubeRVen.A);
        Par.ValveLAv.AOpen= 1.5*Par.ValveLArt.AOpen;
        Par.ValveRAv.AOpen= 1.5*Par.ValveRArt.AOpen;
        
        aux=1.0; % factor representing AmDead / Valve Orifice Area
        Par.La.AmDead= aux*mean(Par.ValveLAv.AOpen+Par.ValveLVen.AOpen...
            +Par.ValveASD.AOpen);
        Par.Ra.AmDead= aux*mean(Par.ValveRAv.AOpen+Par.ValveRVen.AOpen...
            +Par.ValveASD.AOpen);
        Par.Lv.AmDead= aux*mean(Par.ValveLAv.AOpen+Par.ValveLArt.AOpen);
        Par.Sv.AmDead= aux*mean(Par.ValveVSD.AOpen);
        Par.Rv.AmDead= aux*mean(Par.ValveRAv.AOpen+Par.ValveRArt.AOpen);

    end
    Par2InOut;% store output signals

end
%---
% === if Error==small, ending is made faster
if size(Par.Adapt.Out,1)>1; % Escape if steady state is reached
    ErrVec= log( Par.Adapt.Out(end,:)./Par.Adapt.In(end,:) );
    if sqrt(mean(ErrVec .^2 ))<0.001
        Par.General.tEnd= Par.General.tEnd-0.5*(Par.General.tEnd-Par.t(end));
    end
end;
% === Faster Steady State
if Par.Adapt.Fast;
    %=== ERROR criterium on flow stationarity
    SteadyState(0.2); % sets new initial conditions to StrInOut-variables
end
disp(' ');

%=== make ready for next beat
Par2SVar;
CircSVarDot(0,Par.SVar(end,:)',[]);

return

