function CircAdapt
% function Par= CircAdapt(Par);
% Theo Arts, Maastricht University
% April 24, 2008. Email: t.arts@bf.unimaas.nl
% === Solution of differential equations, defined in global structure 'Par'
% Solution of state variables stored in Par.SVar

global Par

Par.SVar=[];
Par2SVar; Par.SVar=Par.SVar(:,end);

% load general parameters
Dt          = Par.General.Dt;
Par.Adapt.In=[]; Par.Adapt.Out=[]; % reset of storage input/output per beat

% solving differential equations
Par2SVar; % setting initial condition of differential equation in Par.SVar

SVar= Par.SVar(end,:); % sets start condition
% Right atriual activation used as start of heart cycle
% tRa= Par.Ra.Sarc.ActivationDelay;
% Rg = find(tRa>Par.t(end)+Dt); % select relevant RA-triggers
% tRa=tRa(Rg); iRa=1; nRa=length(tRa); % tRa=end points of beats
Par.General.tEnd= Par.t(end)+Par.General.DtSimulation;

while Par.t(end)<Par.General.tEnd-Dt;
    Timing;
    
    % Set simulation interval
    nDt= round(Par.General.tCycle/Dt+1); % number of time points
    TimePoints= Par.General.tCycle*(0:nDt)/nDt;
    % existing solution
    disp(['t= ',num2str(Par.t(end)),';  Time to go= ',...
        num2str(Par.General.tEnd-Par.t(end))]); pause(0.01);

    tol=1e-4; %tol= 1e-4 or 1e-5: trade off accuracy and calculation speed
    opt = odeset('RelTol',tol,'AbsTol',tol);
    [tDummy,SVarAppend]= ode113('CircSVarDot',...
        TimePoints,Par.SVar(end,:),opt); % solving of Differential Equations
    SVar= [SVar(1:end-1,:);SVarAppend(1:end,:)]; %appends 1-beat SVar-vector
    % SVar(end,:) removed because of overlap with next beat
    Par.SVar= SVarAppend;
    CircAdaptDisplay; % display and time course of 1-beat hemodynamics
    % Calculation of changes due to adaptation
    feval(Par.Adapt.FunctionName); % Execute AdaptXX
    % Time courses in Par belong to parameter setting before Adapt-action!
end

Par.SVar= SVar; %state variables of all beats to show trends. Be careful,
% because AdaptXX has been applied, the Par-parameters do not belong to the
% Par.SVar. Only for Adapt0 (= no adaptation), complete SVar
% is compatible with parameter settings.

return
