function CircAdaptDisplay
% function P= CircAdaptDisplay
% Theo Arts, Maastricht University
% July 30, 2006, email: t.arts@bf.unimaas.nl
% Reads state variables from Par.SVar,
% makes graphical display of some variables

global Par

CircSVarDot(0,transpose(Par.SVar),[]);

% dependent variables as f(t)
q0          = Par.General.q0;
p0          = Par.General.p0;
tCycle      = Par.General.tCycle;

% scaling of graphics
qSc= Rnd(q0);
VSc= Rnd(q0*tCycle/10);
pSc= Rnd(0.1*p0);

Finish= 0;%++++++++++++++++++no legends
t= Par.t-Par.t(1);

OFFSET= -20;

%==== Hemodynamics
figure(1);
subplot(2,4,[3,4,7,8]); plot(t,[...
    Par.TubeLArt.pIn/pSc,...
    OFFSET+Par.TubeRArt.pIn/pSc,...
    Par.Lv.p/pSc,...
    OFFSET+Par.Rv.p/pSc,...
    Par.Lv.V/VSc,...
    OFFSET+(Par.Rv.V)/VSc,...
    Par.La.V/VSc,...
    OFFSET+Par.Ra.V/VSc,...
    Par.ValveLArt.q/qSc,...
    OFFSET+Par.ValveRArt.q/qSc,...
    Par.ValveLAv.q/qSc,...
    OFFSET+Par.ValveRAv.q/qSc,...
    Par.ValveLVen.q/qSc,...
    OFFSET+Par.ValveRVen.q/qSc,...
    Par.ValveDUCT.q/qSc,...
    Par.ValveVSD.q/qSc,...
    Par.ValveASD.q/qSc]);

if Finish
    legend('pLArt','pRArt','pLv','pRv','VLv','VRv','VLa','VRa','qLArt','qRArt',...
        'qLAv','qRAv','qLVen','qRVen','qDUCT','qRAv','qASD',2);
end
title(['FLOW[',num2str(qSc),']; PRESSURE[',num2str(pSc),']; VOLUME[',...
    num2str(VSc),']']);

Calp= 0.001; CalV= 1e6;
% p-V loops
subplot(2,4,1); plot(...
    CalV*Par.La.V,Calp*Par.La.p,...
    CalV*Par.Ra.V,Calp*Par.Ra.p,...
    CalV*Par.Lv.V,Calp*Par.Lv.p,...
    CalV*Par.Rv.V,Calp*Par.Rv.p);
if Finish
    legend('La','Ra','Lv','Rv','Sv',2);
end

%Sf-Ef loops
EfT = [Par.La.Sarc.Ef,...
    Par.Ra.Sarc.Ef,...
    Par.Lv.Sarc.Ef,...
    Par.Sv.Sarc.Ef,...
    Par.Rv.Sarc.Ef,...
    ];
SfT = [Par.La.Sarc.Sf,...
    Par.Ra.Sarc.Sf,...
    Par.Lv.Sarc.Sf,...
    Par.Sv.Sarc.Sf,...
    Par.Rv.Sarc.Sf,...
    ];
subplot(2,4,2); plot(EfT,SfT);
if Finish
    legend('La','Lv','Ra','Rv','Sv',2);
end

% clipped low venous, atrial and ventricular pressures
aux= 1.2*max(max([Par.La.p,Par.Ra.p]))/pSc;
subplot(2,4,5:6); plot(t,[...
    Par.La.p/pSc,...
    Par.Ra.p/pSc,...
    min(aux,Par.Lv.p/pSc),...
    min(aux,Par.Rv.p/pSc),...
    Par.Peri.p/pSc,...
    Par.TubeLVen.pIn/pSc,...
    Par.TubeRVen.pIn/pSc,...
    ]);
if Finish
    legend('pLVen','pRVen','pLa','pRa','pLv','pRv',2);
end

figure(1); pause(0.1);

% figure(2); plot(EfT,SfT);%++++++++++++++++++++++++++++++++


return

%========== AUXILARY FUNCTIONS =============

function X=Rnd(x)
X1= 10^round(log(x)/log(10));
X2=  2^round(log(x/X1)/log(2));
X=X1*X2;
return

