function [Sheet,Error]= SheetAdapt(Sheet,AdaptType)
% function Sheet= SheetAdapt(Sheet,AdaptType);
% Simulates adaptation of sheet geometry to load

AdaptWallArea=0; AdaptWallVolume=0; AdaptEcmStress =0;
for i=1:length(AdaptType);
    if strcmp(AdaptType{i},'WallArea'  ); AdaptWallArea  =1; end
    if strcmp(AdaptType{i},'WallVolume'); AdaptWallVolume=1; end
    if strcmp(AdaptType{i},'EcmStress' ); AdaptEcmStress =1; end
end
% Correction AmRef by strain EAmRef for TriSeg junction
EAmRef=0; if isfield(Sheet,'EAmRef'); EAmRef=Sheet.EAmRef; end

Sarc= Sheet.Sarc;
Split=0;
if isfield(Sarc,'Sarc')
    SheetMaster=Sheet;
    Sheet=Sarc;
    Sarc=Sheet.Sarc;
    Split=1;
end
    
% Am= mean(Sheet.Am); Cm= mean(Sheet.Cm); VWall= Sheet.VWall;
nt= size(Sheet.Am,1);
Lsi     = Sarc.Lsi;

SfPasT  = Sarc.SfPasT;
SfAct   = max(0, Sarc.Sf-SfPasT);  % active stress
SfPasMax= max(SfPasT);
LsAct   = mean(SfAct.*Lsi)./mean(SfAct); % active stress-weighted Ls
DLs     = 3.0*sqrt(mean(SfAct.*(Lsi-repmat(LsAct,[nt,1])).^2) ./ mean(SfAct));

SfPasMaxAdapt= Sarc.Adapt.SfPasMax; % conventional

FacStrain  = (Sarc.Adapt.LsBe-Sarc.Adapt.LsEe)./DLs;
% Correction AmRef by change of Adapt.SfPasMax for TriSeg junction
FacSfPasM  = SfPasMaxAdapt*exp(-1.0*EAmRef)./SfPasMax; %ECM overstretch
FacLsAct   = (Sarc.Adapt.LsEe+0.60*(Sarc.Adapt.LsBe-Sarc.Adapt.LsEe))./LsAct;

% Clipping of Fac around 1 with range +/-a 
ClipFac= @(x,a) exp(a*tanh(log(x)/a));
Clip=0.5;
FacStrain    = ClipFac(FacStrain    ,Clip);
FacSfPasM    = ClipFac(FacSfPasM    ,Clip);
FacLsAct     = ClipFac(FacLsAct     ,Clip);

% Calculate adaptation factors
switch 2 % various trials, case 2 is besfit matrix, 
    % otherwise is physiological interpretation
    case 1
        % === matrix found by BEST FIT inverse, ParsJ204
        FacVWall= FacStrain.^(+0.25) .* FacSfPasM.^(-0.19) .* FacLsAct.^(-0.23);
        FacAm   = FacStrain.^(-0.35) .* FacSfPasM.^(-0.14) .* FacLsAct.^(+2.3 );
        FacSfPas= FacStrain.^(-0.55) .* FacSfPasM.^(+0.51) .* FacLsAct.^(-4.4 );
        % interpretation to structural remodeling:
        % high sarcomere length -> high ECM force, ECM cross-linking, ECM
        % shrinkage, area decrease, Ls lengthening relative to ECM, AmRef
        % decrease, apparent ECM stiffening, AmRef decrease
        % Hypertrophy by ECM stretch and sarcomere stretch
        % ECM stiffening by stress-weighted strain, sarcomere stretch and low ECM stretch
        % Dilatation by stress-weighted strain and low sarcomere stretch
    case 2 % K930 new sensitivity analysis, works OK
        dEffectdSens=[...
            0.3957   -0.4571   -0.3338
            -0.3066   -0.0433    0.2091
            -0.2350    1.3028   -1.3101];
        Aux= log([FacStrain,FacSfPasM,FacLsAct])*dEffectdSens;
        FacVWall= exp(Aux(1));
        FacAm   = exp(Aux(2));
        FacSfPas= exp(Aux(3));
        
 otherwise % based on case 2, with some physiological interpretation
        % matrix based on HEURISTIC physiologic hypothesis
        % Shifting sarc length over passive matrix for best work range
        FacAm    = FacLsAct.^(+2); % keep Am attached to sarc length 2 um
        FacSfPas = FacLsAct.^(-Sarc.Ls0Pas./Sarc.dLsPas); % increase of sarc
        % length implies apparent change of ECM stiffness
        % Hypertrophy mainly by overstretch of sarcomere
        FacVWall= FacStrain.^(+0.18) .* FacSfPasM.^(-0.19) .* FacLsAct.^(-0.23);
        % Dilatation mainly by strain softening
        FacAm   = FacAm    .* FacStrain.^(-0.35) .* FacSfPasM.^(-0.14) .* FacLsAct.^(+0.3);
        % Tissue softening mainly by (over)stretch of passive matrix
        FacSfPas= FacSfPas .* FacStrain.^(-0.55) .* FacSfPasM.^(+0.51) .* FacLsAct.^(-1.6);
end
a= 0.5; % gain of adaptation feedback. 1.0 represents best fit matrix%+++++++++++++++
FacVWall = FacVWall.^a;
FacAm    = FacAm   .^a;
FacSfPas = FacSfPas.^a;

%=== Carrying out adaptation

Error=[];

%hypertrophy by stretch of passive matrix, preservation of fiber length
if AdaptWallVolume
    Vw0= Sheet.VWall;
    Vw1= Vw0 .* FacVWall;
    Sheet.VWall=Vw1;
    Error= [Error,abs(log(FacVWall))];
end

if AdaptWallArea
    %Strain softening of passive matrix by creep
%     Sheet.AmRef= Sheet.AmRef*FacAm;
    Sheet.AmRef= Sheet.AmRef.*FacAm;
    Error= [Error,abs(log(FacAm))];
end

if AdaptEcmStress 
    % Shifting active sarcomere range over passive matrix
    % Passive stress increase with same sarc length is equivalent with
    % decrease of sarcomere length with same passive stress
    Sarc.SfPas= Sarc.SfPas.*FacSfPas;
    Error= [Error, abs(log(FacSfPas))];
    % Softening by changing dLsPas seems very OK
    %     Sarc.dLsPas= Sarc.dLsPas * FacSfPas.^-0.3;
    %     Error= [Error, abs(log(FacSfPas))];
end

ErrorT= sqrt(mean(Error.^2));
disp(['Strain LsAct FacSfPasM Error*1e3: ',...
    num2str(round(1000*[log([FacStrain,FacLsAct,FacSfPasM]),ErrorT]),'%+5.3d') ]);
Sheet.Sarc= Sarc;

if Split==1; %if sheet has been split in patches
    VWall=sum(Sheet.VWall);
    AmRef=sum(Sheet.AmRef);
    SheetMaster.Sarc=Sheet;
    SheetMaster.VWall= VWall;
    SheetMaster.AmRef= AmRef;
    Sheet=SheetMaster;
end
return
