function Sheet= SheetMech(Sheet)
% function Sheet= SheetMech(Sheet);
% mechanics of a patch of curved thick-walled muscular wall
% matrix proof

% global Par
nSarc= Sheet.nSarc;

if nSarc>1
    Sheet= MultiPatch(Sheet);
else
    Sarc= Sheet.Sarc;
    Sarc.Am   = Sheet.Am - Sheet.AmDead; %midwall area of myo-wall
    Sarc.Cm   = Sheet.Cm   ; %curvature=1/r midwall
%     nt=size(Sarc.Am,1);
    Sarc.VWall= Sheet.VWall; %wall volume
    Sarc.AmRef= Sheet.AmRef; %wall area in reference state
%     Col1      = ones(nt,1);

    Sarc=PatchMech(Sarc);
    
    Sheet.Sarc   = Sarc;
    Sheet.T      = Sarc.T;
    Sheet.pTrans = Sarc.pTrans;
    Sheet.DTDAm  = Sarc.DTDAm;
end

return
%=====================================================================
%=====================Auxilary functions==============================

function Sarc =PatchMech(Sarc)
% Patch data are stored in structure Sarc
% [nt,ns]= number of [time points, patches]
% INPUT: midwall area: Am(nt,ns), midwall curvature:Cm(nt,ns),
% patch wall volume: VWall(ns), reference midwall area: AmRef(ns)
% Output: [wall tension, transmural pressure, wall area stiffness]=
% [T,pTrans,DTDAm](nt,ns)
    Am   = Sarc.Am;
    Cm   = Sarc.Cm;
    VWall= Sarc.VWall;
    AmRef= Sarc.AmRef;
    nt= size(Am,1);
%     [nt,ns]=size(Am);
    
    % dimensionless z for wall thickness to cavity radius
    z   = 1.5*repmat(VWall,[nt,1]).*(Cm./Am); z2=z.^2; z4=z2.^2;
    % for thick-walled sphere: z=VWall/2Vm

    % TDSf= 0.5*VWall*(1+z2/3+z4/5+....)./Am;
    TDSf= ( 0.5*(1+0.27*z2)./Am ) .* repmat(VWall,[nt,1]); % best work balance TdA/SfdEf
    % Polynomial approximate of ratio wall tension/fiber stress.

    % Sheet fiber strain
    Sarc.Ef= 0.5*log(Am./repmat(AmRef,[nt,1])) -z2/12 -0.019*z4;
    Sarc   = SarcMech(Sarc);
    Sf     = Sarc.Sf; % stress

    % Output variables of SarcMech
    Sarc.T      = TDSf .* Sf; % wall tension
    Sarc.pTrans = 2 * Sarc.T .* Cm; % transmural pressure
    Sarc.DTDAm  = 0.5 * TDSf .* Sarc.DSfDEf ./ Am; % sheet stiffness
   
return

function Sheet= MultiPatch(Sheet)

CmSh  = Sheet.Cm;  %curvature fu(t)
AmSh  = Sheet.Am - Sheet.AmDead; % area fu(t)
nt    = size(AmSh,1); % number of time points
nSarc = Sheet.nSarc; % number of patches (nSarc)
Sarc  = Sheet.Sarc ; % represents array of patches/sarcomeres
VWall = Sarc.VWall; % wall volume row (nSarc)
AmRef = Sarc.AmRef; % row (nSarc)
Sheet.VWall= sum(VWall,2); % scalar
Lsi   = Sarc.Lsi; % matrix(nt,nSarc)
LsRef = Sarc.LsRef; % row (nSarc)

% filling Patches with first estimate of Am with Ls=Lsi
AmLsi = Lsi.^2 .* repmat(AmRef./LsRef.^2,[nt,1]); %Am for Ls=Lsi
Sarc.Am = AmLsi; %initial estimate
Sarc.Cm = repmat(CmSh,[1,nSarc]); %initial estimate

%==== Patch wall tension
Sarc=PatchMech(Sarc);

% solve areas of Patches on balance of Tension
% Equations: sum(Patch.Am)==(AmSh=Sheet.Am-Sheet.AmDead)
% All Patch.T are equal

niT=1; %number of iterations, a single iteration is already quite good 
for i=1:niT 
    dAdT    = 1./Sarc.DTDAm; % compliance per patch
    DADT    = sum(dAdT,2); % total compliance
    TSh     = sum(Sarc.T .* Sarc.Am,2)./sum(Sarc.Am,2);%+++
    ATSh    = Sarc.Am - (Sarc.T-repmat(TSh,[1,nSarc])) .* dAdT;
    %                                      TSh stress Am per patch
    DAmSh   = AmSh - sum(ATSh,2); % series elastic dAm, column vector
    DTSh    = DAmSh ./ DADT; % Sheet tension
    Sarc.Am = ATSh + repmat(DTSh,[1,nSarc]).*dAdT;
    Sarc    = PatchMech(Sarc); % maybe iterations are needed
end;

Sheet.Sarc  = Sarc; % collection of patches
Sheet.T     = sum(Sarc.T.*Sarc.Am,2)./sum(Sarc.Am,2);
Sheet.pTrans= 2 * Sheet.T .* (Sarc.Cm*VWall') /Sheet.VWall ; % transmural pressure
Sheet.DTDAm = 1./DADT;

return


