function Timing
% function Timing;
% Theo Arts, Maastricht University, May 26, 2008
% Renders arrays of activation times (Sarc.ActivationDelay) per sarcomere
% Start of simulation: Par.t(end)
% Duration of simulation: Par.General.DtSimulation.
% To be executed at the beginning of a simulation CircAdapt(Par)
% Allows variation of spread of activation and irregular heart beat
%SHOULD BE IMPROVED!!!!

global Par
DtLa   = 0.00;       % dispersion activation time
DtRa   = 0.00;       % dispersion activation time
DtLv   = 0.00;       % dispersion activation time
DtSv   = 0.00;       % dispersion activation time
DtRv   = 0.05;       % dispersion activation time

% Reading timing parameters
G        = Par.General;
tCycleRef= G.tCycleRest ; % Reference tCycle for body size scaling
tCycle   = G.tCycle     ; % current cycle time
TimeFac  = G.TimeFac    ; % scaling of contraction time
TauAv    = G.TauAv      ; % AV-delay, controlled in Adapt0

% TimeAct [s] duration of contraction for Ls==LsStress0Act (s)
ta=0.15*(tCycle/0.85)*TimeFac;
tv=(0.10*tCycleRef +0.40*tCycle)*TimeFac;
Par.La= TimeAct(Par.La, ta );
Par.Ra= TimeAct(Par.Ra, ta );
Par.Lv= TimeAct(Par.Lv, tv );
Par.Sv= TimeAct(Par.Sv, tv );
Par.Rv= TimeAct(Par.Rv, tv );

% Delay times electrical activation
tRa2La= 0.02 * (tCycleRef/0.85) * TimeFac;
tRa2Rv= TauAv; % AV-Delay
tRv2Lv= -0.00;       % pacing delay LBBB, negative: prepacing
tRv2Sv= 0.5*tRv2Lv;  % pacing delay LBBB, negative: prepacing
tRa2Ra= tCycle;      % cycle time
% tRa2Ra= tRa2Ra*(1+0.3*(rand-0.5)); % irregular HR

%TRIAL, CAN BE IMPROVED+++++++++++++++++++++++++++++++
% Time interval of simulation
tStart= Par.t(end);
tEnd  = tStart+tCycle; % assume Ra as main trigger for activation

tRa=tStart; tLa=[]; tLv=[]; tSv=[]; tRv=[];
t=tStart;
while t<tEnd;
    tLa = [tLa; tRa(end) + tRa2La];
    tRv = [tRv; tRa(end) + tRa2Rv];
    tSv = [tSv; tRv(end) + tRv2Sv];
    tLv = [tLv; tRv(end) + tRv2Lv];
    tRa = [tRa; tRa(end) + tRa2Ra];
    t= tRa(end); % start new cycle
end

% sub sheets not implemented yet
Par.Ra= Append2Last(Par.Ra,tRa,tCycle,DtRa);
Par.La= Append2Last(Par.La,tLa,tCycle,DtLa);
Par.Lv= Append2Last(Par.Lv,tLv,tCycle,DtLv);
Par.Sv= Append2Last(Par.Sv,tSv,tCycle,DtSv);
Par.Rv= Append2Last(Par.Rv,tRv,tCycle,DtRv);

return


function Sheet = Append2Last(Sheet,tTrig,tCycle,tDisp)
% Appends set of new trigger times to last used trigger time
% tTrig= successive new trigger times
% tCycle is used to determine default trigger time

nSarc=Sheet.nSarc;
Dt=( (1:nSarc)-0.5*(nSarc+1) )/nSarc * tDisp;
a0=(tTrig(1)-tCycle);
a=[a0;mean(Sheet.Sarc.ActivationDelay,2)];
a0= min( a(end),tTrig(1) );
tTrig1=[a0;tTrig];
nt= size(tTrig1,1);
Sheet.Sarc.ActivationDelay= repmat(tTrig1,[1,nSarc])+repmat(Dt,[nt,1]);
return

function Sheet=TimeAct(Sheet,tAct)
Sheet.Sarc.TimeAct=repmat(tAct,[1,Sheet.nSarc]);
return
